==> gcloud-oauth-vue-0.3.6.tgz: package/src/store/modules/permit.js <==
import { Empty } from 'google-protobuf/google/protobuf/empty_pb'
import { oauthUserClient } from '../../oauth_user_request'

const state = {
    //角色缓存
    roles:[],
    //权限缓存
    perms:[],
    //组织角色缓存
    organRoles:[],
    //组织权限缓存
    organPerms:[]
}

const mutations = {
  SET_ROLES: (state, roles) => {
    state.roles = roles;
  },
  SET_PERMS: (state, perms) => {
    state.perms = perms;
  },
  SET_ORGAN_ROLES: (state, organRoles) => {
    state.organRoles = organRoles;
  },
  SET_ORGAN_PERMS: (state, organPerms) => {
    state.organPerms = organPerms;
  }
}

const actions = {
    //用户角色缓存
    userRoles({state,commit}) {
      console.log("PERMS1 : "+state.roles);
      return new Promise((resolve, reject) => {
          //登录判断
          let roles = state.roles;
          console.log("ROLES1 : "+roles);
          if (roles.length > 0){
            resolve(roles);
          }
          //获取角色
          let empty =new Empty();
          oauthUserClient.userRoles(empty).then((response) =>{
              roles = response.toObject().roleNameList;
              commit("SET_ROLES", roles);
              console.log("ROLES3 : "+roles);
              resolve(roles);
          }).catch(err => {
              reject(err)
          })
      });
    },
    //用户权限缓存
    userPerms({state,commit}) {
      return  new Promise((resolve, reject) => {
          //登录判断
          let perms = state.perms;
          if (perms.length > 0){
            resolve(perms);
          }
          //获取角色
          let empty =new Empty();
          oauthUserClient.userPerms(empty).then((response) =>{
              perms = response.toObject().permNameList;
              commit("SET_PERMS", perms);
              resolve(perms);
          }).catch(err => {
              reject(err)
          })
      });
    },
    //是否包含该角色
    hasRole({dispatch},role){
      return  new Promise((resolve, reject) => {
           dispatch("userRoles").then(roles =>{
              resolve(roles.indexOf(role) !== -1)
           }).catch(err => {
              reject(err);
           });
      });
    },
    //是否包含权限
    hasPermission({dispatch},perm){
      return  new Promise((resolve, reject) => {
        dispatch("userPerms").then(perms =>{
          resolve(perm.filter(function (val) {
            if(perms.indexOf(val)>-1){
              return true
            }
          }))
        }).catch(err => {
          reject(err);
        });
      });
    },
    clear({ commit }) {
       commit("SET_ROLES", {});
       commit("SET_PERMS", {});
       commit("SET_ORGAN_ROLES", {});
       commit("SET_ORGAN_PERMS", {});
    }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}

==> gcloud-oauth-vue-1.0.9.tgz: package/src/store/modules/permit.js <==
import { Empty } from 'google-protobuf/google/protobuf/empty_pb'
import { oauthUserClient } from '../../oauth_user_request'

const state = {
    //角色缓存
    roles:[],
    //权限缓存
    perms:[],
    //组织角色缓存
    organRoles:[],
    //组织权限缓存
    organPerms:[]
}

const mutations = {
  SET_ROLES: (state, roles) => {
    state.roles = roles;
  },
  SET_PERMS: (state, perms) => {
    state.perms = perms;
  },
  SET_ORGAN_ROLES: (state, organRoles) => {
    state.organRoles = organRoles;
  },
  SET_ORGAN_PERMS: (state, organPerms) => {
    state.organPerms = organPerms;
  }
}

const actions = {
    //用户角色缓存
    userRoles({state,commit}) {
      //console.log("ROLES0 : "+state.roles);
      return new Promise((resolve, reject) => {
          //登录判断
          let roles = state.roles;
          console.log("ROLES1 : "+roles);
          if (roles.length > 0){
            resolve(roles);
          }else{
            //获取角色
            let empty =new Empty();
            oauthUserClient.userRoles(empty).then((response) =>{
                roles = response.toObject().roleNameList;
                commit("SET_ROLES", roles);
                console.log("ROLES3 : "+roles);
                resolve(roles);
            }).catch(err => {
                reject(err)
            })
          }
      });
    },
    //用户权限缓存
    userPerms({state,commit}) {
      return  new Promise((resolve, reject) => {
            //权限判断
          let perms = state.perms;
          //console.log("PERMS 1: "+perms);
          if (perms.length > 0){
            resolve(perms);
          }else{
            //获取权限
            let empty =new Empty();
            oauthUserClient.userPerms(empty).then((response) =>{
                perms = response.toObject().permNameList;
                commit("SET_PERMS", perms);
                console.log("PERMS 3: "+perms);
                resolve(perms);
            }).catch(err => {
                reject(err)
            })
          }
      });
    },
    //是否包含该角色
    hasRole({dispatch},role){
      return  new Promise((resolve, reject) => {
           dispatch("userRoles").then(roles =>{
              resolve(roles.indexOf(role) !== -1)
           }).catch(err => {
              reject(err);
           });
      });
    },
    //是否包含权限
    hasPermission({dispatch},perm){
      return  new Promise((resolve, reject) => {
        dispatch("userPerms").then(perms =>{
          resolve(perm.filter(function (val) {
            if(perms.indexOf(val)>-1){
              return true
            }
          }))
        }).catch(err => {
          reject(err);
        });
      });
    },
    clear({ commit }) {
       commit("SET_ROLES", {});
       commit("SET_PERMS", {});
       commit("SET_ORGAN_ROLES", {});
       commit("SET_ORGAN_PERMS", {});
    }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
